diff mbox

[1/2] mac80211: add monitor interface into PS disable list

Message ID 1297253799-9688-1-git-send-email-rmanoharan@atheros.com (mailing list archive)
State Not Applicable, archived
Headers show

Commit Message

Rajkumar Manoharan Feb. 9, 2011, 12:16 p.m. UTC
None
diff mbox

Patch

diff --git a/net/mac80211/mlme.c b/net/mac80211/mlme.c
index f77adf1..8fc6d35 100644
--- a/net/mac80211/mlme.c
+++ b/net/mac80211/mlme.c
@@ -630,13 +630,13 @@  void ieee80211_recalc_ps(struct ieee80211_local *local, s32 latency)
 	list_for_each_entry(sdata, &local->interfaces, list) {
 		if (!ieee80211_sdata_running(sdata))
 			continue;
-		if (sdata->vif.type == NL80211_IFTYPE_AP) {
-			/* If an AP vif is found, then disable PS
-			 * by setting the count to zero thereby setting
-			 * ps_sdata to NULL.
+		if ((sdata->vif.type == NL80211_IFTYPE_AP) ||
+		    (sdata->vif.type == NL80211_IFTYPE_MONITOR)) {
+			/* If an AP/monitor vif is found, then disable PS
+			 * by setting ps_sdata to NULL.
 			 */
-			count = 0;
-			break;
+			local->ps_sdata = NULL;
+			goto change;
 		}
 		if (sdata->vif.type != NL80211_IFTYPE_STATION)
 			continue;